# roadmap

后续开发方向将围绕三个主题展开：

## 速度类型的精确测试

正如首页中的例子，它已经被落地到多个实际的速度类型测试场景中：

- 启动速度
- 页面切换速度
- 开关机
- ...

## 功能测试

- 基于 [视频比较功能](https://github.com/williamfzc/stagesepx/tree/master/example)
- 理论上，在无异常发生的情况下，同样的操作流程 -> 同样的页面效果 -> 同样的视频 -> 同样（类似）的阶段
- 以功能测试为例，我们只需要比较每次回归产生的视频，即可知道页面是否符合预期
- 基于此，你同样可以将它用于兼容性测试中，用于检测UI渲染是否正常

## AI数据采集

- classifier本身就是基于机器学习实现的
- 你完全可以利用cutter从视频中提取素材，用于训练你自己的AI模型
- 或者，用你手工采集的数据集来训练模型
- 细节请参见 [设计理念与定位](/pages/3_how_it_works)

## 或者，更多想法？

非常欢迎有想法的开发者加入我们，请直接通过 [issue面板](https://github.com/williamfzc/stagesepx/issues) 分享你的想法即可！ 

如果你希望加入这个项目亲自为它开发一些新特性，请同样从 [issue面板](https://github.com/williamfzc/stagesepx/issues) 开始。所有的开发流程会同步在上面，你可以通过它了解该项目的开发进展及近期方向。
